@@ -32,7 +32,7 @@
 SDLAppDisplay display;
 
 SDLAppDisplay::SDLAppDisplay() {
-    clearColour = vec3f(0.0f,0.0f,0.0f);
+    clearColour = vec4f(0.0f,0.0f,0.0f,1.0f);
     enable_shaders=false;
     enable_alpha=false;
     vsync=false;
@@ -43,6 +43,10 @@ SDLAppDisplay::~SDLAppDisplay() {
 }
 
 void SDLAppDisplay::setClearColour(vec3f colour) {
+    setClearColour(vec4f(colour, enable_alpha ? 0.0f : 1.0f));
+}
+
+void SDLAppDisplay::setClearColour(vec4f colour) {
     clearColour = colour;
 }
 
@@ -56,11 +60,9 @@ void SDLAppDisplay::enableVsync(bool vsync) {
     this->vsync = vsync;
 }
 
-#ifdef SDLAPP_SHADER_SUPPORT
 void SDLAppDisplay::enableShaders(bool enable) {
     enable_shaders = enable;
 }
-#endif
 
 void SDLAppDisplay::enableAlpha(bool enable) {
     enable_alpha = enable;
@@ -70,6 +72,19 @@ void SDLAppDisplay::multiSample(int samples) {
     multi_sample = samples;
 }
 
+void SDLAppDisplay::setupARBExtensions() {
+
+    GLenum err = glewInit();
+
+    if (GLEW_OK != err) {
+        /* Problem: glewInit failed, something is seriously wrong. */
+        char glewerr[1024];
+        snprintf(glewerr, 1024, "GLEW Error: %s", glewGetErrorString(err));
+
+        throw SDLInitException(std::string(glewerr));
+    }
+}
+
 void SDLAppDisplay::init(std::string window_title, int width, int height, bool fullscreen) {
 
     this->width  = width;
@@ -79,9 +94,14 @@ void SDLAppDisplay::init(std::string window_title, int width, int height, bool f
 
     int flags = SDLFlags(fullscreen);
 
-    SDL_Init(SDL_INIT_TIMER | SDL_INIT_VIDEO);
+    if(SDL_Init(SDL_INIT_TIMER | SDL_INIT_VIDEO) != 0) {
+        throw SDLInitException(SDL_GetError());
+    }
+
     atexit(SDL_Quit);
 
+    SDL_EnableUNICODE(1);
+
     //vsync
     if(vsync) SDL_GL_SetAttribute(SDL_GL_SWAP_CONTROL, 1);
     else SDL_GL_SetAttribute(SDL_GL_SWAP_CONTROL, 0);
@@ -109,16 +129,11 @@ void SDLAppDisplay::init(std::string window_title, int width, int height, bool f
 #endif
 
     if (!surface) {
-        printf("SDL initalization failed: %s\n", SDL_GetError());
-        exit(1);
+        std::string sdlerr(SDL_GetError());
+        throw SDLInitException(sdlerr);
     }
 
-
-#ifdef SDLAPP_SHADER_SUPPORT
-    if(enable_shaders) {
-        setupARBExtensions();
-    }
-#endif
+    setupARBExtensions();
 
     SDL_WM_SetCaption(window_title.c_str(),0);
 }
@@ -133,7 +148,7 @@ void SDLAppDisplay::update() {
 }
 
 void SDLAppDisplay::clear() {
-    glClearColor(clearColour.x, clearColour.y, clearColour.z, 1.0f);
+    glClearColor(clearColour.x, clearColour.y, clearColour.z, clearColour.w);
     glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
 }
 
@@ -153,6 +168,24 @@ void SDLAppDisplay::mode2D() {
     glLoadIdentity();
 }
 
+void SDLAppDisplay::push2D() {
+    glMatrixMode(GL_PROJECTION);
+        glPushMatrix();
+        glLoadIdentity();
+            glOrtho(0, display.width, display.height, 0, -1.0, 1.0);
+
+    glMatrixMode(GL_MODELVIEW);
+        glPushMatrix();
+        glLoadIdentity();
+}
+
+void SDLAppDisplay::pop2D() {
+        glMatrixMode(GL_PROJECTION);
+        glPopMatrix();
+        glMatrixMode(GL_MODELVIEW);
+        glPopMatrix();
+}
+
 vec4f SDLAppDisplay::currentColour() {
     vec4f colour;
    	glGetFloatv(GL_CURRENT_COLOR, colour);
@@ -163,31 +196,50 @@ void SDLAppDisplay::checkGLErrors() {
 //TODO
 }
 
-void SDLAppDisplay::renderToTexture(GLuint target, int width, int height, GLenum internalFormat) {
-	glBindTexture(GL_TEXTURE_2D, target);
-	glCopyTexImage2D(GL_TEXTURE_2D, 0, internalFormat, 0, 0, width, height, 0);
+void SDLAppDisplay::fullScreenQuad(bool coord_flip) {
+
+    int y1 = coord_flip ? 0 : 1;
+    int y2 = coord_flip ? 1 : 0;
+
+    glBegin(GL_QUADS);
+        glTexCoord2i(0,y1);
+        glVertex2f(0, 0);
+
+        glTexCoord2i(1,y1);
+        glVertex2i(display.width, 0);
+
+        glTexCoord2i(1,y2);
+        glVertex2i(display.width, display.height);
+
+        glTexCoord2i(0,y2);
+        glVertex2i(0, display.height);
+    glEnd();
 }
 
-GLuint SDLAppDisplay::emptyTexture(int width, int height) {
-	GLuint txtnumber;   // Texture ID
-	unsigned int* data;	// Stored Data
-
-    //blank source
-	data = (unsigned int*)new GLuint[((width * height)* 4 * sizeof(unsigned int))];
-    memset(data,0,((width * height)* 4 * sizeof(unsigned int)));
-
-    glGenTextures(1, &txtnumber);					// Create 1 Texture
-	glBindTexture(GL_TEXTURE_2D, txtnumber);			// Bind The Texture
-	glTexImage2D(GL_TEXTURE_2D, 0, 4, width, height, 0,
-		GL_RGBA, GL_UNSIGNED_BYTE, data);			// Build Texture Using Information In data
-	glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_LINEAR);
-	glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_LINEAR);
-
-	delete [] data;
-	return txtnumber;
+void SDLAppDisplay::renderToTexture(GLuint target, int width, int height, GLenum format) {
+    glEnable(GL_TEXTURE_2D);
+    glBindTexture(GL_TEXTURE_2D, target);
+    glCopyTexImage2D(GL_TEXTURE_2D, 0, format, 0, 0, width, height, 0);
 }
 
-GLuint SDLAppDisplay::createTexture(int width, int height, int mipmaps, int clamp, int trilinear, int format, unsigned int* data) {
+GLuint SDLAppDisplay::emptyTexture(int width, int height, GLenum format) {
+    GLuint textureid;
+
+    glEnable(GL_TEXTURE_2D);
+
+    glGenTextures(1, &textureid);
+    glBindTexture(GL_TEXTURE_2D, textureid);
+
+    glTexImage2D(GL_TEXTURE_2D, 0, 4, width, height, 0,
+        GL_RGBA, GL_UNSIGNED_BYTE, 0);
+
+    glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_LINEAR);
+    glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_LINEAR);
+
+    return textureid;
+}
+
+GLuint SDLAppDisplay::createTexture(int width, int height, bool mipmaps, bool clamp, bool trilinear, GLenum format, unsigned int* data) {
 
     GLuint textureid;
 
