@@ -29,7 +29,11 @@
 #ifndef SDLAPP_DISPLAY_H
 #define SDLAPP_DISPLAY_H
 
-#include "extensions.h"
+#include <GL/glew.h>
+
+#define NO_SDL_GLEXT
+#include "SDL.h"
+#include "SDL_opengl.h"
 
 #include "logger.h"
 #include "vectors.h"
@@ -44,6 +48,16 @@
 #include <vector>
 #include <string>
 
+class SDLInitException : public std::exception {
+protected:
+    std::string error;
+public:
+    SDLInitException(const std::string& error) : error(error) {}
+    virtual ~SDLInitException() throw () {};
+
+    virtual const char* what() const throw() { return error.c_str(); }
+};
+
 class SDLAppDisplay {
     SDL_Surface *surface;
 
@@ -53,11 +67,12 @@ class SDLAppDisplay {
 
     int  multi_sample;
 
-    int    SDLFlags(bool fullscreen);
+    int  SDLFlags(bool fullscreen);
+    void setupARBExtensions();
 public:
     int width, height;
     bool fullscreen;
-    vec3f clearColour;
+    vec4f clearColour;
 
     SDLAppDisplay();
     ~SDLAppDisplay();
@@ -70,10 +85,9 @@ public:
     void   clear();
     void   enableVsync(bool vsync);
     void   setClearColour(vec3f colour);
+    void   setClearColour(vec4f colour);
 
-#ifdef SDLAPP_SHADER_SUPPORT
     void   enableShaders(bool enable);
-#endif
 
     void   enableAlpha(bool enable);
     void   multiSample(int sample);
@@ -81,11 +95,16 @@ public:
     void   mode3D(float fov, float znear, float zfar);
     void   mode2D();
 
+    void   push2D();
+    void   pop2D();
+
     vec4f  currentColour();
 
-    void   renderToTexture(GLuint target, int width, int height, GLenum internalFormat);
-    GLuint emptyTexture(int width, int height);
-    GLuint createTexture(int width, int height, int mipmaps, int clamp, int trilinear, int format, unsigned int* data);
+    void fullScreenQuad(bool coord_flip);
+
+    void   renderToTexture(GLuint target, int width, int height, GLenum format);
+    GLuint emptyTexture(int width, int height, GLenum format);
+    GLuint createTexture(int width, int height, bool mipmaps, bool clamp, bool trilinear, GLenum format, unsigned int* data);
 
     vec3f project(vec3f pos);
     vec3f unproject(vec2f pos);
