@@ -18,19 +18,12 @@
 #include "dirnode.h"
 
 float gGourceMinDirSize   = 15.0;
-float gGourceMaxSpeed     = 1000.0f;
 
 float gGourceForceGravity = 10.0;
 float gGourceDirPadding   = 1.5;
 
-float gGourceElasticity   = 0.0;
-
-float gGourceBloomMultiplier = 1.0;
-float gGourceBloomIntensity  = 0.75;
-
 bool  gGourceNodeDebug    = false;
 bool  gGourceGravity      = true;
-bool  gGourceDrawDirName  = true;
 
 //debugging
 int  gGourceDirNodeInnerLoops = 0;
@@ -38,7 +31,7 @@ int  gGourceFileInnerLoops = 0;
 
 std::map<std::string, RDirNode*> gGourceDirMap;
 
-RDirNode::RDirNode(RDirNode* parent, std::string abspath) {
+RDirNode::RDirNode(RDirNode* parent, const std::string & abspath) {
 
     changePath(abspath);
 
@@ -74,19 +67,19 @@ RDirNode::RDirNode(RDirNode* parent, std::string abspath) {
     calcColour();
 }
 
-void RDirNode::changePath(std::string abspath) {
+void RDirNode::changePath(const std::string & abspath) {
     //fix up path
-    if(abspath.size() == 0 || abspath[abspath.size()-1] != '/') {
-        abspath = abspath + std::string("/");
-    }
 
     gGourceDirMap.erase(this->abspath);
+    this->abspath = abspath;
+
+    if(abspath.empty() || abspath[abspath.size()-1] != '/') {
+        this->abspath += std::string("/");
+    }
 
     //debugLog("new dirnode %s\n", abspath.c_str());
 
-    this->abspath = abspath;
-
-    gGourceDirMap[abspath] = this;
+    gGourceDirMap[this->abspath] = this;
 }
 
 RDirNode::~RDirNode() {
@@ -97,7 +90,7 @@ RDirNode::~RDirNode() {
     gGourceDirMap.erase(abspath);
 }
 
-int RDirNode::getTokenOffset() {
+int RDirNode::getTokenOffset() const{
     return path_token_offset;
 }
 
@@ -131,36 +124,31 @@ void RDirNode::rotate(float s, float c) {
     }
 }
 
-void RDirNode::setPos(vec2f pos) {
+void RDirNode::setPos(const vec2f & pos) {
     this->pos = pos;
 }
 
 //returns true if supplied path prefixes the nodes path
-bool RDirNode::prefixedBy(std::string path) {
-    if(path.size()==0) return false;
+bool RDirNode::prefixedBy(const std::string & path) const {
+    if(path.empty()) return false;
 
-    if(path[path.size()-1] != '/') {
-        path = path + std::string("/");
-    }
-
-    int pos = abspath.find(path);
-
-    if(pos==0) return true;
-
-    return false;
+    if(path[path.size()-1] != '/')
+        return abspath.find(path + std::string("/")) == 0;
+    else
+        return abspath.find(path) == 0;
 }
 
-std::string RDirNode::getPath() {
+const std::string & RDirNode::getPath() const{
     return abspath;
 }
 
 
 
-RDirNode* RDirNode::getParent() {
+RDirNode* RDirNode::getParent() const{
     return parent;
 }
 
-int RDirNode::getDepth() {
+int RDirNode::getDepth() const{
     return depth;
 }
 
@@ -198,7 +186,6 @@ void RDirNode::setParent(RDirNode* parent) {
     }
 }
 
-
 void RDirNode::addNode(RDirNode* node) {
     // does this node prefix any other nodes, if so, add them to it
 
@@ -262,10 +249,13 @@ bool RDirNode::removeFile(RFile* f) {
         bool removed = node->removeFile(f);
 
         if(removed) {
+            //fprintf(stderr, "%s file removed from a child. child file count=%d, dir count =%d\n", getPath().c_str(), node->fileCount(), node->dirCount());
+            //node->printFiles();
+
             //node is now empty, reap!
-            if(node->fileCount()==0 && node->dirCount()==0) {
+            if(node->noFiles() && node->noDirs()) {
                 children.erase(it);
-                debugLog("deleting node %s...\n", node->getPath().c_str());
+                //fprintf(stderr, "deleting node %s from %s\n", node->getPath().c_str(), getPath().c_str());
                 delete node;
                 nodeUpdated(false);
             }
@@ -277,6 +267,15 @@ bool RDirNode::removeFile(RFile* f) {
     return false;
 }
 
+
+void RDirNode::printFiles() {
+    for(std::list<RFile*>::iterator it = files.begin(); it != files.end(); it++) {
+        RFile* file = (*it);
+        fprintf(stderr, "%s: %s %s%s%s\n", getPath().c_str(), file->fullpath.c_str() , file->isExpiring() ? "expiring " : "", file->isRemoving() ? "removing " : "", file->isHidden() ? "hidden " : "");
+    }
+}
+
+
 void RDirNode::addVisible() {
     visible_count++;
     visible = true;
@@ -286,7 +285,7 @@ bool RDirNode::isVisible() {
 
     if(visible) return true;
 
-    for(std::list<RDirNode*>::iterator it = children.begin(); it != children.end(); it++) {
+    for(std::list<RDirNode*>::const_iterator it = children.begin(); it != children.end(); it++) {
         if((*it)->isVisible()) {
             visible = true;
             return true;
@@ -296,16 +295,20 @@ bool RDirNode::isVisible() {
     return false;
 }
 
-int RDirNode::visibleFileCount() {
+int RDirNode::visibleFileCount() const{
     return visible_count;
 }
 
-int RDirNode::fileCount() {
+int RDirNode::fileCount() const{
     return files.size();
 }
 
-std::string RDirNode::commonPathPrefix(std::string& str) {
-    int c = 0;
+bool RDirNode::noFiles() const{
+    return files.empty();
+}
+
+std::string RDirNode::commonPathPrefix(const std::string & str) const{
+    size_t c = 0;
     int slash = -1;
 
     while(c<abspath.size() && c<str.size() && abspath[c] == str[c]) {
@@ -324,7 +327,12 @@ bool RDirNode::addFile(RFile* f) {
     //doesnt match this path at all
     if(f->path.find(abspath) != 0) {
 
-        if(parent!=0) return false;
+        if(parent != 0) return false;
+
+        //if this is the root node (ie no parent), we fork it
+        //if we encounter a file with a non matching path to the
+        //current root path. the calling process then checks if
+        //the root now has a parent node, and changes the pointer.
 
         RDirNode* newparent;
 
@@ -338,7 +346,7 @@ bool RDirNode::addFile(RFile* f) {
 
     //simply change path of node and add this to it
     if(   parent==0 && abspath == "/"
-       && f->path.compare(abspath) != 0 && fileCount()==0 && dirCount()==0) {
+       && f->path.compare(abspath) != 0 && noFiles() && noDirs()) {
         debugLog("modifying root path to %s\n", f->path.c_str());
         changePath(f->path);
     }
@@ -356,15 +364,34 @@ bool RDirNode::addFile(RFile* f) {
         return true;
     }
 
+    bool added = false;
+
     //does this belong to one of the children ?
     for(std::list<RDirNode*>::iterator it = children.begin(); it != children.end(); it++) {
         RDirNode* child =  (*it);
 
-        bool added = child->addFile(f);
+        added = child->addFile(f);
 
-        if(added) return true;
+        if(added) break;
     }
 
+    if(added && parent != 0) return true;
+
+    //do we have a file in this directory thats fullpath is a prefix of this file, if so
+    //that file is actually a directory - the file should be removed, and a directory with that path added
+    //if this is the root node we do this regardless of if the file was added to a child node
+    for(std::list<RFile*>::const_iterator it = files.begin(); it != files.end(); it++) {
+        RFile* file = (*it);
+
+        if(f->path.find(file->fullpath) == 0) {
+            //fprintf(stderr, "removing %s as is actually the directory of %s\n", file->fullpath.c_str(), f->fullpath.c_str());
+            file->remove(true);
+            break;
+        }
+    }
+
+    if(added) return true;
+
     //add new child, add it to that
     //if commonpath is longer than abspath, add intermediate node, else just add at the files path
     RDirNode* node = new RDirNode(this, f->path);
@@ -415,20 +442,24 @@ bool RDirNode::addFile(RFile* f) {
     return true;
 }
 
-float RDirNode::getRadius() {
+float RDirNode::getParentRadius() const{
+    return parent_radius;
+}
+
+float RDirNode::getRadius() const{
     return dir_radius;
 }
 
-float RDirNode::getRadiusSqrt() {
+float RDirNode::getRadiusSqrt() const{
     return dir_radius_sqrt;
 }
 
-vec3f RDirNode::averageFileColour() {
+vec3f RDirNode::averageFileColour() const{
 
     vec3f av;
     int count = 0;
 
-    for(std::list<RFile*>::iterator it = files.begin(); it != files.end(); it++) {
+    for(std::list<RFile*>::const_iterator it = files.begin(); it != files.end(); it++) {
         RFile* file = (*it);
 
         if(file->isHidden()) continue;
@@ -442,7 +473,7 @@ vec3f RDirNode::averageFileColour() {
 
     count = 0;
 
-    for(std::list<RDirNode*>::iterator it = children.begin(); it != children.end();it++) {
+    for(std::list<RDirNode*>::const_iterator it = children.begin(); it != children.end();it++) {
             RDirNode* child =  (*it);
 
             av += child->averageFileColour();
@@ -454,7 +485,7 @@ vec3f RDirNode::averageFileColour() {
     return av;
 }
 
-vec4f RDirNode::getColour() {
+const vec4f & RDirNode::getColour() const{
     return col;
 }
 
@@ -483,41 +514,36 @@ void RDirNode::calcColour() {
     this->col /= (float) fcount + 1.0;
 }
 
-void RDirNode::calcArea() {
+float RDirNode::getArea() const{
+    return dir_area;
+}
+
+void RDirNode::calcRadius() {
 
     float total_file_area = file_area * visible_count;
 
     dir_area = total_file_area;
 
+    //float parent_circ        = 0.0;
+
     for(std::list<RDirNode*>::iterator it = children.begin(); it != children.end(); it++) {
         RDirNode* node = (*it);
 
         dir_area += node->getArea();
+    //    parent_circ += node->getRadiusSqrt();
     }
-}
 
-float RDirNode::getArea() {
-    return dir_area;
-}
-
-void RDirNode::calcRadius() {
-    calcArea();
-
-    // was gGourceMinDirSize
     this->dir_radius = std::max(1.0f, (float)sqrt(dir_area)) * gGourceDirPadding;
-    this->dir_radius_sqrt = sqrt(dir_radius);
+    //this->dir_radius_sqrt = sqrt(dir_radius); //dir_radius_sqrt is not used
+
+//    this->parent_radius = std::max(1.0, parent_circ / PI);
+    this->parent_radius = std::max(1.0, sqrt(total_file_area) * gGourceDirPadding);
 }
 
-float RDirNode::distanceTo(RDirNode* node) {
+float RDirNode::distanceToParent() const{
 
-    float posd        = (node->getPos() - pos).length();
-    float myradius    = getRadius();
-
-    float your_radius = std::max(1.0, sqrt((node->visibleFileCount() * file_area)) * gGourceDirPadding);
-
-    float sumradius = myradius + your_radius;
-
-    float distance = posd - sumradius;
+    float posd     = (parent->getPos() - pos).length();
+    float distance = posd - (dir_radius + parent->getParentRadius());
 
     return distance;
 }
@@ -525,9 +551,7 @@ float RDirNode::distanceTo(RDirNode* node) {
 void RDirNode::applyForceDir(RDirNode* node) {
     if(node == this) return;
 
-    vec2f node_pos = node->getPos();
-
-    vec2f dir = node_pos - pos;
+    vec2f dir = node->getPos() - pos;
 
     float posd2       = dir.length2();
     float myradius    = getRadius();
@@ -552,22 +576,22 @@ void RDirNode::applyForceDir(RDirNode* node) {
     accel += distance * dir.normal();
 }
 
-vec2f RDirNode::getPos() {
+const vec2f & RDirNode::getPos() const{
     return pos;
 }
 
-bool RDirNode::isParentOf(RDirNode* node) {
+bool RDirNode::isParent(RDirNode* node) const {
+    if(node==parent) return true;
+    if(parent==0) return false;
 
-    if(node->prefixedBy(abspath)) return true;
-
-    return false;
+    return parent->isParent(node);
 }
 
-bool RDirNode::empty() {
-    return (visible_count==0 && dirCount()==0) ? true : false;
+bool RDirNode::empty() const{
+    return (visible_count==0 && noDirs()) ? true : false;
 }
 
-void RDirNode::applyForces(QuadTree& quadtree) {
+void RDirNode::applyForces(QuadTree & quadtree) {
 
     //child nodes
     for(std::list<RDirNode*>::iterator it = children.begin(); it != children.end(); it++) {
@@ -578,40 +602,15 @@ void RDirNode::applyForces(QuadTree& quadtree) {
 
     if(parent == 0) return;
 
-    std::vector<QuadItem*> inbounds;
-    int found = quadtree.getItemsInBounds(inbounds, quadItemBounds);
-
-    std::set<std::string> seen;
-    std::set<std::string>::iterator seentest;
-
-    //apply forces with other that are inside the 'box' of this nodes radius
-    for(std::vector<QuadItem*>::iterator it = inbounds.begin(); it != inbounds.end(); it++) {
-
-        RDirNode* d = (RDirNode*) (*it);
-
-        if(d==this) continue;
-        if(d==parent) continue;
-        if(d->parent==this) continue;
-
-        if((seentest = seen.find(d->getPath())) != seen.end()) {
-            continue;
-        }
-
-        seen.insert(d->getPath());
-
-        if(isParentOf(d)) continue;
-        if(d->isParentOf(this)) continue;
-
-        applyForceDir(d);
-
-        gGourceDirNodeInnerLoops++;
-    }
+    DirForceFunctor dff(this);
+    quadtree.visitItemsInBounds(quadItemBounds, dff);
+    gGourceDirNodeInnerLoops += dff.getLoopCount();
 
     //always call on parent no matter how far away
     applyForceDir(parent);
 
     //pull towards parent
-    float parent_dist = distanceTo(parent);
+    float parent_dist = distanceToParent();
 
     //  * dirs should attract to sit on the radius of the parent dir ie:
     //    should attract to distance_to_parent * normal_to_parent
@@ -631,13 +630,13 @@ void RDirNode::applyForces(QuadTree& quadtree) {
     }
 
     //  * dirs should repulse from other dirs of this parent
-    std::list<RDirNode*>* siblings = parent->getChildren();
-    if(siblings->size() > 0) {
+    const std::list<RDirNode*> & siblings = parent->getChildren();
+    if(!siblings.empty()) {
         vec2f sib_accel;
 
         int visible = 1;
 
-        for(std::list<RDirNode*>::iterator it = siblings->begin(); it != siblings->end(); it++) {
+        for(std::list<RDirNode*>::const_iterator it = siblings.begin(); it != siblings.end(); it++) {
             RDirNode* node = (*it);
 
             if(node == this) continue;
@@ -659,22 +658,22 @@ void RDirNode::applyForces(QuadTree& quadtree) {
 
 }
 
-void RDirNode::debug(int indent) {
+void RDirNode::debug(int indent) const{
     std::string indentstr;
     while(indentstr.size() < indent) indentstr += " ";
 
     debugLog("%s%s\n", indentstr.c_str(), abspath.c_str());
 
-    for(std::list<RDirNode*>::iterator it = children.begin(); it != children.end(); it++) {
+    for(std::list<RDirNode*>::const_iterator it = children.begin(); it != children.end(); it++) {
         RDirNode* node = (*it);
         node->debug(indent+1);
     }
 }
 
-int RDirNode::totalFileCount() {
+int RDirNode::totalFileCount() const{
     int total = visibleFileCount();
 
-    for(std::list<RDirNode*>::iterator it = children.begin(); it != children.end(); it++) {
+    for(std::list<RDirNode*>::const_iterator it = children.begin(); it != children.end(); it++) {
         RDirNode* node = (*it);
         total += node->visibleFileCount();
     }
@@ -682,10 +681,10 @@ int RDirNode::totalFileCount() {
     return total;
 }
 
-int RDirNode::totalDirCount() {
+int RDirNode::totalDirCount() const{
     int total = 1;
 
-    for(std::list<RDirNode*>::iterator it = children.begin(); it != children.end(); it++) {
+    for(std::list<RDirNode*>::const_iterator it = children.begin(); it != children.end(); it++) {
         RDirNode* node = (*it);
         total += node->totalDirCount();
     }
@@ -693,12 +692,16 @@ int RDirNode::totalDirCount() {
     return total;
 }
 
-int RDirNode::dirCount() {
+int RDirNode::dirCount() const{
     return children.size();
 }
 
-std::list<RDirNode*>* RDirNode::getChildren() {
-    return &children;
+bool RDirNode::noDirs() const{
+    return children.empty();
+}
+
+const std::list<RDirNode*> & RDirNode::getChildren() const{
+    return children;
 }
 
 void RDirNode::updateSpline(float dt) {
@@ -751,10 +754,10 @@ void RDirNode::move(float dt) {
 
     pos += accel * dt;
 
-    if(gGourceElasticity>0.0) {
+    if(gGourceSettings.elasticity>0.0) {
         vec2f diff = (accel - prev_accel);
 
-        float m = dt * gGourceElasticity;
+        float m = dt * gGourceSettings.elasticity;
 
         vec2f accel3 = prev_accel * (1.0-m) + diff * m;
         pos += accel3;
@@ -765,7 +768,7 @@ void RDirNode::move(float dt) {
     accel = vec2f(0.0, 0.0);
 }
 
-vec2f RDirNode::getNodeNormal() {
+const vec2f & RDirNode::getNodeNormal() const{
     return node_normal;
 }
 
@@ -785,6 +788,7 @@ void RDirNode::updateFilePositions() {
     int max_files = 1;
     int diameter  = 1;
     int file_no   = 0;
+    float d = 0.0;
 
     int files_left = visible_count;
 
@@ -799,8 +803,6 @@ void RDirNode::updateFilePositions() {
 
         vec2f dest = calcFileDest(max_files, file_no);
 
-        float d = ((float)(diameter-1)) * gGourceFileDiameter;
-
         f->setDest(dest);
         f->setDistance(d);
 
@@ -809,6 +811,7 @@ void RDirNode::updateFilePositions() {
 
         if(file_no>=max_files) {
             diameter++;
+            d += gGourceFileDiameter;
             max_files = (int) std::max(1.0, diameter*PI);
 
             if(files_left<max_files) {
@@ -871,80 +874,65 @@ void RDirNode::logic(float dt) {
     since_last_node_change += dt;
 }
 
-void RDirNode::drawDirName(FXFont& dirfont) {
-    if(!gGourceDrawDirName) return;
+void RDirNode::drawDirName(const FXFont& dirfont) const{
+    if(gGourceSettings.hide_dirnames) return;
 
-    if(since_last_node_change > 5.0) return;
+    if(!gGourceSettings.highlight_dirs && since_last_node_change > 5.0) return;
 
-    float alpha = std::max(0.0f, 5.0f - since_last_node_change) / 5.0f;
+    float alpha = gGourceSettings.highlight_dirs ? 1.0 : std::max(0.0f, 5.0f - since_last_node_change) / 5.0f;
 
     glColor4f(1.0, 1.0, 1.0, alpha);
 
-    vec3f screenpos = display.project(vec3f(0.0, 0.0, 0.0));
-
-    glMatrixMode(GL_PROJECTION);
-        glPushMatrix();
-        glLoadIdentity();
-            glOrtho(0, display.width, display.height, 0, -1.0, 1.0);
-
-        glMatrixMode(GL_MODELVIEW);
-            glPushMatrix();
-            glLoadIdentity();
-
-        dirfont.draw(screenpos.x, screenpos.y, path_token);
-
-        glMatrixMode(GL_PROJECTION);
-        glPopMatrix();
-
-        glMatrixMode(GL_MODELVIEW);
-        glPopMatrix();
+    dirfont.draw(screenpos.x, screenpos.y, path_token);
 }
 
-void RDirNode::drawNames(FXFont& dirfont, Frustum& frustum) {
 
-    glPushMatrix();
-    glTranslatef(pos.x, pos.y, 0.0);
+// project positions of files and directories on the display in 2d
+void RDirNode::calcScreenPos() {
 
-    if(isVisible()) {
+    screenpos = display.project(vec3f(pos.x, pos.y, 0.0));
+
+    //first pass - calculate positions of names
+    for(std::list<RFile*>::const_iterator it = files.begin(); it!=files.end(); it++) {
+            RFile* f = *it;
+
+            // TODO: different offsets for selected/not selected
+            if(f->isSelected())
+                f->calcScreenPos(pos + vec2f(5.5f, -2.0f));
+            else
+                f->calcScreenPos(pos + vec2f(5.5f, -1.0f));
+    }
+
+    for(std::list<RDirNode*>::const_iterator it = children.begin(); it != children.end(); it++) {
+        RDirNode* node = (*it);
+        node->calcScreenPos();
+    }
+}
+
+void RDirNode::drawNames(const FXFont & dirfont, const Frustum & frustum){
+
+    if(!gGourceSettings.hide_dirnames && isVisible()) {
         drawDirName(dirfont);
     }
 
-    if(!(gGourceHideFilenames||gGourceHideFiles) && frustum.boundsInFrustum(quadItemBounds)) {
-        for(std::list<RFile*>::iterator it = files.begin(); it!=files.end(); it++) {
-            RFile* f = *it;
-            f->drawName();
+    if(!gGourceSettings.hide_filenames) {
+
+        if(!(gGourceSettings.hide_filenames || gGourceSettings.hide_files) && frustum.boundsInFrustum(quadItemBounds)) {
+            for(std::list<RFile*>::const_iterator it = files.begin(); it!=files.end(); it++) {
+                RFile* f = *it;
+                f->drawName();
+            }
         }
+
     }
 
-    glPopMatrix();
-
-
-    for(std::list<RDirNode*>::iterator it = children.begin(); it != children.end(); it++) {
+    for(std::list<RDirNode*>::const_iterator it = children.begin(); it != children.end(); it++) {
         RDirNode* node = (*it);
         node->drawNames(dirfont,frustum);
     }
 }
 
-void RDirNode::drawBeam(vec2f pos_src, vec4f col_src, vec2f pos_dest, vec4f col_dest, float beam_radius) {
-
-    vec2f perp = (pos_src - pos_dest).perpendicular().normal();
-
-    // src point
-    glColor4fv(col_src);
-    glTexCoord2f(0.0,0.0);
-    glVertex2f(pos_src.x - perp.x * beam_radius, pos_src.y - perp.y * beam_radius);
-    glTexCoord2f(1.0,0.0);
-    glVertex2f(pos_src.x + perp.x * beam_radius, pos_src.y + perp.y * beam_radius);
-
-    // dest point
-    glColor4fv(col_dest);
-    glTexCoord2f(1.0,0.0);
-    glVertex2f(pos_dest.x + perp.x * beam_radius, pos_dest.y + perp.y * beam_radius);
-    glTexCoord2f(0.0,0.0);
-    glVertex2f(pos_dest.x - perp.x * beam_radius, pos_dest.y - perp.y * beam_radius);
-}
-
-void RDirNode::drawShadows(Frustum &frustum, float dt) {
+void RDirNode::drawShadows(const Frustum & frustum, float dt) const{
 
     if(frustum.boundsInFrustum(quadItemBounds)) {
 
@@ -952,7 +940,7 @@ void RDirNode::drawShadows(Frustum &frustum, float dt) {
         glTranslatef(pos.x, pos.y, 0.0);
 
         //draw files
-        for(std::list<RFile*>::iterator it = files.begin(); it!=files.end(); it++) {
+        for(std::list<RFile*>::const_iterator it = files.begin(); it!=files.end(); it++) {
             RFile* f = *it;
             if(f->isHidden()) continue;
 
@@ -962,13 +950,13 @@ void RDirNode::drawShadows(Frustum &frustum, float dt) {
         glPopMatrix();
     }
 
-    for(std::list<RDirNode*>::iterator it = children.begin(); it != children.end(); it++) {
+    for(std::list<RDirNode*>::const_iterator it = children.begin(); it != children.end(); it++) {
         RDirNode* node = (*it);
         node->drawShadows(frustum, dt);
     }
 }
 
-void RDirNode::drawFiles(Frustum &frustum, float dt) {
+void RDirNode::drawFiles(const Frustum & frustum, float dt) const{
 
     if(frustum.boundsInFrustum(quadItemBounds)) {
 
@@ -979,7 +967,7 @@ void RDirNode::drawFiles(Frustum &frustum, float dt) {
 
             //draw files
 
-            for(std::list<RFile*>::iterator it = files.begin(); it!=files.end(); it++) {
+            for(std::list<RFile*>::const_iterator it = files.begin(); it!=files.end(); it++) {
                 RFile* f = *it;
                 if(f->isHidden()) continue;
 
@@ -991,17 +979,17 @@ void RDirNode::drawFiles(Frustum &frustum, float dt) {
 
     glDisable(GL_TEXTURE_2D);
 
-    for(std::list<RDirNode*>::iterator it = children.begin(); it != children.end(); it++) {
+    for(std::list<RDirNode*>::const_iterator it = children.begin(); it != children.end(); it++) {
         RDirNode* node = (*it);
         node->drawFiles(frustum,dt);
     }
 }
 
-vec2f RDirNode::getSPos() {
+const vec2f & RDirNode::getSPos() const{
     return projected_spos;
 }
 
-vec2f RDirNode::getProjectedPos() {
+const vec2f & RDirNode::getProjectedPos() const{
     return projected_pos;
 }
 
@@ -1010,41 +998,43 @@ void RDirNode::calcProjectedPos() {
     projected_spos = display.project(vec3f(spos.x, spos.y, 0.0)).truncate();
 }
 
-void RDirNode::drawEdgeShadows(float dt) {
+void RDirNode::drawEdgeShadows(float dt) const{
 
-    for(std::list<RDirNode*>::iterator it = children.begin(); it != children.end(); it++) {
+    for(std::list<RDirNode*>::const_iterator it = children.begin(); it != children.end(); it++) {
         RDirNode* child = (*it);
 
-        //draw edge
+        //draw edge - assumes calcEdges() called before hand so spline will exist
         if(child->isVisible()) {
-           splines[child].drawShadow();
+           std::map<RDirNode*, SplineEdge>::const_iterator it = splines.find(child);
+           if(it != splines.end()) it->second.drawShadow();
 
            child->drawEdgeShadows(dt);
         }
     }
 }
 
-void RDirNode::drawEdges(float dt) {
+void RDirNode::drawEdges(float dt) const{
 
-    for(std::list<RDirNode*>::iterator it = children.begin(); it != children.end(); it++) {
+    for(std::list<RDirNode*>::const_iterator it = children.begin(); it != children.end(); it++) {
         RDirNode* child = (*it);
 
-        //draw edge
+        //draw edge - assumes calcEdges() called before hand so spline will exist
         if(child->isVisible()) {
-           splines[child].draw();
+           std::map<RDirNode*, SplineEdge>::const_iterator it = splines.find(child);
+           if(it != splines.end()) it->second.draw();
 
            child->drawEdges(dt);
         }
     }
 }
 
-void RDirNode::drawBloom(Frustum& frustum, float dt) {
+void RDirNode::drawBloom(const Frustum & frustum, float dt){
 
     if(isVisible() && frustum.boundsInFrustum(quadItemBounds)) {
 
-        float bloom_radius = dir_radius * 2.0 * gGourceBloomMultiplier;
+        float bloom_radius = dir_radius * 2.0 * gGourceSettings.bloom_multiplier;
 
-        vec4f bloom_col = col * gGourceBloomIntensity;
+        vec4f bloom_col = col * gGourceSettings.bloom_intensity;
 
         glColor4f(bloom_col.x, bloom_col.y, bloom_col.z, 1.0);
 
@@ -1065,27 +1055,27 @@ void RDirNode::drawBloom(Frustum& frustum, float dt) {
 
     }
 
-    for(std::list<RDirNode*>::iterator it = children.begin(); it != children.end(); it++) {
+    for(std::list<RDirNode*>::const_iterator it = children.begin(); it != children.end(); it++) {
         RDirNode* node = (*it);
         node->drawBloom(frustum,dt);
     }
 }
 
-void RDirNode::drawSimple(Frustum& frustum, float dt) {
+void RDirNode::drawSimple(const Frustum & frustum, float dt) const{
 
     glDisable(GL_TEXTURE_2D);
 
     if(frustum.boundsInFrustum(quadItemBounds)) {
         glPushMatrix();
             glTranslatef(pos.x, pos.y, 0.0);
-            for(std::list<RFile*>::iterator it = files.begin(); it!=files.end(); it++) {
+            for(std::list<RFile*>::const_iterator it = files.begin(); it!=files.end(); it++) {
                 RFile* f = *it;
                 f->drawSimple(dt);
             }
         glPopMatrix();
     }
 
-    for(std::list<RDirNode*>::iterator it = children.begin(); it != children.end(); it++) {
+    for(std::list<RDirNode*>::const_iterator it = children.begin(); it != children.end(); it++) {
         RDirNode* node = (*it);
         node->drawSimple(frustum,dt);
     }
