@@ -34,6 +34,8 @@ class RFile : public Pawn {
     RDirNode* dir;
 
     bool removing;
+    bool expiring;
+
     float last_action;
 
     float radius;
@@ -43,49 +45,51 @@ class RFile : public Pawn {
 
     GLuint namelist;
 
+    std::string shortname;
+
     void setPath();
-    vec3f getNameColour();
-    void drawNameText(float alpha);
+    const vec3f& getNameColour() const;
+    void drawNameText(float alpha) const;
 public:
     std::string path;
     std::string fullpath;
 
-    RFile(std::string name, vec3f colour, vec2f pos, int tagid);
+    RFile(const std::string & name, const vec3f & colour, const vec2f & pos, int tagid);
     ~RFile();
 
-    vec3f getFileColour();
-    vec3f getColour();
+    bool isExpiring() const { return expiring; }
+    bool isRemoving() const { return removing; }
+    
+    const vec3f & getFileColour() const;
+    vec3f getColour() const;
 
-    float getAlpha();
+    float getAlpha() const;
 
-    void touch(vec3f colour);
+    void touch(const vec3f & colour);
 
-    std::string getFullPath();
+    const std::string & getFullPath() const;
 
     void setSelected(bool selected);
 
     void setHidden(bool hidden);
 
-    void setDest(vec2f dest);
-    void setDistance(float distance);
+    void setDest(const vec2f & dest){ this->dest = dest; }
+    void setDistance(float distance){ this->distance = distance; }
 
     void logic(float dt);
     void draw(float dt);
 
-    void remove();
+    void remove(bool force=false);
 
-    vec2f getAbsolutePos();
+    vec2f getAbsolutePos() const;
 
-    RDirNode* getDir();
+    RDirNode* getDir() const;
     void setDir(RDirNode* dir);
 
-    int getPathHash();
+    int getPathHash() const;
 };
 
-extern float gGourceMaxFileIdle;
 extern float gGourceFileDiameter;
-extern bool gGourceHideFilenames;
-extern bool gGourceHideFiles;
 
 extern std::vector<RFile*> gGourceRemovedFiles;
 
