@@ -18,14 +18,12 @@
 #ifndef GOURCE_H
 #define GOURCE_H
 
-#define GOURCE_VERSION "0.26"
-
 #ifdef _WIN32
 #include "windows.h"
 #endif
 
 #include <deque>
-#include <dirent.h>
+#include <fstream>
 
 #include "core/display.h"
 #include "core/sdlapp.h"
@@ -34,6 +32,10 @@
 #include "core/seeklog.h"
 #include "core/frustum.h"
 #include "core/regex.h"
+#include "core/ppm.h"
+#include "core/mousecursor.h"
+
+#include "gource_settings.h"
 
 #include "git.h"
 #include "hg.h"
@@ -50,31 +52,23 @@
 #include "user.h"
 #include "dirnode.h"
 #include "zoomcamera.h"
-#include "ppm.h"
-
-void createWindowsConsole();
-
-void gource_help();
-void gource_info(std::string msg);
-void gource_quit(std::string error);
 
 class Gource : public SDLApp {
     std::string logfile;
 
     FrameExporter* frameExporter;
 
-    std::vector<std::string> follow_users;
-    std::vector<std::string> highlight_users;
-    std::vector<Regex*> filters;
-
     RCommitLog* commitlog;
     PositionSlider slider;
     ZoomCamera camera;
 
-    vec3f background_colour;
-
     bool debug, trace_debug;
 
+    bool manual_rotate;
+
+    MouseCursor cursor;
+
+    bool grab_mouse;
     bool mousemoved;
     bool mouseclicked;
     bool mousedragged;
@@ -86,12 +80,9 @@ class Gource : public SDLApp {
     vec2f backgroundPos;
     bool backgroundSelected;
 
-    float start_position, stop_position;
     float last_percent;
     float time_scale;
 
-    bool stop_at_end;
-    bool stop_on_idle;
     bool stop_position_reached;
 
     int tag_seq, commit_seq;
@@ -113,6 +104,8 @@ class Gource : public SDLApp {
 
     TextureResource* bloomtex;
     TextureResource* beamtex;
+    TextureResource* logotex;
+    TextureResource* backgroundtex;
 
     FXFont font, fontlarge, fontmedium;
 
@@ -125,6 +118,7 @@ class Gource : public SDLApp {
     int framecount;
 
     time_t currtime;
+    time_t lasttime;
     float runtime;
     float subseconds;
 
@@ -138,6 +132,8 @@ class Gource : public SDLApp {
     Uint32 draw_time;
     Uint32 logic_time;
     Uint32 trace_time;
+    Uint32 name_calc_time;
+    Uint32 name_draw_time;
 
     bool track_users;
 
@@ -153,8 +149,12 @@ class Gource : public SDLApp {
     QuadTree* dirNodeTree;
     QuadTree* userTree;
 
+    std::string message;
+    float message_timer;
+
+    void setMessage(const char* str, ...);
+
     void reset();
-    void findUserImages();
 
     void deleteUser(RUser* user);
     void deleteFile(RFile* file);
@@ -181,7 +181,7 @@ class Gource : public SDLApp {
     void updateQuadTree();
     void updateBounds();
 
-    void updateTime();
+    void updateTime(time_t display_time);
 
     void mousetrace(Frustum& frustum, float dt);
 
@@ -195,22 +195,17 @@ class Gource : public SDLApp {
     void drawActions(float dt);
     void drawTree(Frustum &frustum, float dt);
     void drawBloom(Frustum &frustum, float dt);
+
+    void screenshot();
 public:
-    Gource(std::string logfile);
+    Gource(FrameExporter* frameExporter = 0);
     ~Gource();
 
-    void setBackground(vec3f background);
+    void setCameraMode(const std::string& mode);
     void setCameraMode(bool track_users);
-    void setStopPosition(float percent);
-    void setStartPosition(float percent);
-    void setStopAtEnd(bool stop_at_end);
-    void setStopOnIdle(bool stop_on_idle);
     void setFrameExporter(FrameExporter* exporter, int video_framerate);
-    void showSplash();
 
-    void addFollowUser(std::string user);
-    void addHighlightUser(std::string user);
-    void addFilter(Regex* filter);
+    void showSplash();
 
     void logic(float t, float dt);
     void draw(float t, float dt);
@@ -222,19 +217,4 @@ public:
     void mouseClick(SDL_MouseButtonEvent *e);
 };
 
-extern float gGourceAutoSkipSeconds;
-extern bool  gGourceDrawBackground;
-extern bool  gGourceHideUsernames;
-extern bool  gGourceDisableBloom;
-extern bool  gGourceHideDate;
-extern bool  gGourceHideTree;
-extern bool  gGourceDisableProgress;
-extern bool  gGourceFileLoop;
-extern int   gGourceMaxFiles;
-
-extern std::string gGourceLogFormat;
-extern std::string gGourceDateFormat;
-
-extern bool  gGourceHighlightAllUsers;
-
 #endif
