@@ -31,23 +31,21 @@ Pawn::Pawn(std::string name, vec2f pos, int tagid) {
 
     shadow = false;
 
-    this->shadowOffset = vec2f(2.0, 2.0);
+    namewidth = 0;
 
+    this->shadowOffset = vec2f(2.0, 2.0);
     this->elapsed = 0.0;
     this->fadetime = 1.0;
     this->nametime = 5.0;
     this->name_interval = 0.0;
     this->namecol = vec3f(1.0, 1.0, 1.0);
+    this->selectedcol = vec3f(1.0, 1.0, 0.3);
 }
 
 float Pawn::getSize() {
     return size;
 }
 
-vec2f Pawn::getPos() {
-    return pos;
-}
-
 void Pawn::setPos(vec2f pos) {
     this->pos = pos;
 }
@@ -60,15 +58,6 @@ void Pawn::showName() {
     if(name_interval <= 0.0) name_interval = nametime;
 }
 
-void Pawn::setHidden(bool hidden) {
-    showName();
-    this->hidden = false;
-}
-
-bool Pawn::isHidden() {
-    return hidden;
-}
-
 void Pawn::updateQuadItemBounds() {
 
     float ratio = icon->h / (float) icon->w;
@@ -103,11 +92,15 @@ std::string Pawn::getName() {
     return name;
 }
 
-vec3f Pawn::getNameColour() {
+const vec3f& Pawn::getNameColour() const {
     return namecol;
 }
 
-void Pawn::drawNameText(float alpha) {
+void Pawn::calcScreenPos(const vec2f& offset) {
+    screenpos = display.project(vec3f(pos.x+offset.x, pos.y+offset.y, 0.0f));
+}
+
+void Pawn::drawNameText(float alpha) const {
 
     if(alpha>0.0) {
         vec3f nameCol = getNameColour();
@@ -117,17 +110,16 @@ void Pawn::drawNameText(float alpha) {
 
         glColor4f(nameCol.x, nameCol.y, nameCol.z, alpha);
 
-        float namewidth = font.getWidth(name);
         font.draw(pos.x - ((float)namewidth/2.0), pos.y - size*1.2, name.c_str()); // above player
     }
 }
 
 
-bool Pawn::nameVisible() {
+bool Pawn::nameVisible() const {
     return (!selected && name_interval < 0.0 || isHidden()) ? false : true;
 }
 
-void Pawn::drawName() {
+void Pawn::drawName() const {
     if(!nameVisible()) return;
 
     float done = nametime - name_interval;
@@ -209,8 +201,6 @@ void Pawn::drawShadow(float dt) {
 void Pawn::draw(float dt) {
     if(hidden) return;
 
-    glLoadName(tagid);
-
     glEnable(GL_BLEND);
     glEnable(GL_TEXTURE_2D);
 
