@@ -17,34 +17,18 @@
 
 #include "user.h"
 
-float gGourceBeamDist = 100.0;
-float gGourceActionDist = 50.0;
-float gGourceMaxUserIdle = 3.0;
+float gGourceBeamDist          = 100.0;
+float gGourceActionDist        = 50.0;
 float gGourcePersonalSpaceDist = 100.0;
-float gGourceMaxFileLagSeconds = 5.0;
-float gGourceMaxUserSpeed      = 500.0;
-float gGourceUserFriction      = 1.0;
-float gGourceUserScale         = 1.0;
-
-bool gGourceColourUserImages = false;
-
-std::map<std::string, std::string> gGourceUserImageMap;
-std::string gGourceUserImageDir;
-std::string gGourceDefaultUserImage;
-
-//fractions of days per second
-float gGourceDaysPerSecond = 0.1;
-
-bool gGourceHideUsers = false;
 
 RUser::RUser(std::string name, vec2f pos, int tagid) : Pawn(name,pos,tagid) {
 
     this->name = name;
 
-    speed = gGourceMaxUserSpeed;
-    size = 20.0 * gGourceUserScale;
+    speed = gGourceSettings.max_user_speed;
+    size = 20.0 * gGourceSettings.user_scale;
 
-    shadowOffset = vec2f(2.0, 2.0) * gGourceUserScale;
+    shadowOffset = vec2f(2.0, 2.0) * gGourceSettings.user_scale;
 
     shadow = true;
 
@@ -59,6 +43,8 @@ RUser::RUser(std::string name, vec2f pos, int tagid) : Pawn(name,pos,tagid) {
     name_interval = 5.0;
 
     min_units_ps = 100.0;
+
+    actionCount = activeCount = 0;
 }
 
 void RUser::addAction(RAction* action) {
@@ -66,6 +52,7 @@ void RUser::addAction(RAction* action) {
     if(action->source != this) return;
 
     actions.push_back(action);
+    actionCount++;
 }
 
 // remove references to this file
@@ -76,6 +63,7 @@ void RUser::fileRemoved(RFile* f) {
         if(a->target == f) {
             it = actions.erase(it);
             delete a;
+            actionCount--;
             continue;
         }
 
@@ -106,7 +94,7 @@ void RUser::applyForceUser(RUser* u) {
 
     //different repelling force depending on how busy the user is
     float desired_dist = getActionCount() == 0 ?
-        gGourcePersonalSpaceDist : (actions.size()>0 && activeActions.size()==0) ?
+        gGourcePersonalSpaceDist : (!actions.empty() && activeActions.empty()) ?
             gGourcePersonalSpaceDist * 0.1 : gGourcePersonalSpaceDist * 0.5;
 
     //resolve overlap
@@ -150,7 +138,7 @@ void RUser::applyForceAction(RAction* action) {
 }
 
 void RUser::applyForceToActions() {
-    if(activeActions.size()==0 && actions.size()==0) return;
+    if(activeActions.empty() && actions.empty()) return;
 
     last_action = elapsed;
 
@@ -168,7 +156,7 @@ void RUser::applyForceToActions() {
         if(action_influence >= max_influence) break;
     }
 
-    if(activeActions.size()!=0) return;
+    if(!activeActions.empty()) return;
 
     //if no actions being worked on, move towards one pending action
     for(std::list<RAction*>::iterator it = actions.begin(); it != actions.end(); it++) {
@@ -189,23 +177,23 @@ void RUser::assignIcon() {
 
     bool image_assigned = false;
 
-    if(gGourceUserImageDir.size() > 0) {
+    if(gGourceSettings.user_image_dir.size() > 0) {
 
         //try thier username
         // TODO: replace with map of name -> image of all pngs and jpgs in directory
-        //gGourceUserImageDir + name + std::string(".jpg");
+        //gGourceSettings.user_image_dir + name + std::string(".jpg");
 
         std::map<std::string, std::string>::iterator findimage;
 
-        findimage = gGourceUserImageMap.find(name);
+        findimage = gGourceSettings.user_image_map.find(name);
 
         //do we have this image
-        if(findimage != gGourceUserImageMap.end()) {
+        if(findimage != gGourceSettings.user_image_map.end()) {
             std::string imagefile = findimage->second;
 
-            if(!gGourceColourUserImages) usercol = vec3f(1.0, 1.0, 1.0);
+            if(!gGourceSettings.colour_user_images) usercol = vec3f(1.0, 1.0, 1.0);
 
-            icon = texturemanager.grab(imagefile, 1, 1, 0, true);
+            icon = texturemanager.grabFile(imagefile);
 
             setHighlighted(true);
 
@@ -215,9 +203,9 @@ void RUser::assignIcon() {
 
     //nope
     if(!image_assigned) {
-        if(gGourceDefaultUserImage.size() > 0) {
-            if(!gGourceColourUserImages) usercol = vec3f(1.0, 1.0, 1.0);
-            icon = texturemanager.grab(gGourceDefaultUserImage, 1, 1, 0, true);
+        if(gGourceSettings.default_user_image.size() > 0) {
+            if(!gGourceSettings.colour_user_images) usercol = vec3f(1.0, 1.0, 1.0);
+            icon = texturemanager.grabFile(gGourceSettings.default_user_image);
         } else {
             icon = texturemanager.grab("no_photo.png");
         }
@@ -228,11 +216,11 @@ void RUser::assignIcon() {
 }
 
 int RUser::getActionCount() {
-    return actions.size() + activeActions.size();
+    return actionCount + activeCount;
 }
 
 int RUser::getPendingActionCount() {
-    return actions.size();
+    return actionCount;
 }
 
 void RUser::logic(float t, float dt) {
@@ -242,7 +230,7 @@ void RUser::logic(float t, float dt) {
 
     bool find_nearby_action = false;
 
-    if(actions.size() && action_interval <= 0) {
+    if(!actions.empty() && action_interval <= 0) {
         find_nearby_action = true;
     }
 
@@ -251,10 +239,12 @@ void RUser::logic(float t, float dt) {
         RAction* action = *it;
 
         //add all files which are too old
-        if(gGourceMaxFileLagSeconds>=0.0 && action->addedtime < t - gGourceMaxFileLagSeconds) {
+        if(gGourceSettings.max_file_lag>=0.0 && action->addedtime < t - gGourceSettings.max_file_lag) {
             it = actions.erase(it);
+            actionCount--;
             action->rate = 2.0;
             activeActions.push_back(action);
+            activeCount++;
             continue;
         }
 
@@ -266,6 +256,7 @@ void RUser::logic(float t, float dt) {
         if(action_dist < gGourceBeamDist) {
             it = actions.erase(it);
             activeActions.push_back(action);
+            actionCount--; activeCount++;
             break;
         }
 
@@ -274,7 +265,7 @@ void RUser::logic(float t, float dt) {
 
     //reset action interval
     if(action_interval <= 0) {
-        int total_actions = actions.size() + activeActions.size();
+        int total_actions = actionCount + activeCount;
 
         action_interval = total_actions ? (1.0 / (float)total_actions) : 1.0;
     }
@@ -289,6 +280,7 @@ void RUser::logic(float t, float dt) {
         if(action->isFinished()) {
             it = activeActions.erase(it);
             delete action;
+            activeCount--;
             continue;
         }
 
@@ -301,11 +293,11 @@ void RUser::logic(float t, float dt) {
 
     pos += accel * dt;
 
-    accel = accel * std::max(0.0f, (1.0f - gGourceUserFriction*dt));
+    accel = accel * std::max(0.0f, (1.0f - gGourceSettings.user_friction*dt));
 
     //ensure characters dont crawl
 //     float accel_amount = accel.length();
-//     if(actions.size()>0 && accel_amount > 0.0 && accel_amount < min_units_ps) {
+//     if(!actions.empty() && accel_amount > 0.0 && accel_amount < min_units_ps) {
 //         accel = accel.normal() * min_units_ps;
 //     }
 
@@ -337,11 +329,11 @@ void RUser::setSelected(bool selected) {
     updateFont();
 }
 
-vec3f RUser::getNameColour() {
-    return (selected||highlighted) ? vec3f(1.0, 1.0, 0.3) : namecol;
+const vec3f& RUser::getNameColour() const {
+    return (selected||highlighted) ? selectedcol : namecol;
 }
 
-vec3f RUser::getColour() {
+vec3f RUser::getColour() const{
     if(selected) return vec3f(1.0, 1.0, 1.0);
 
     return usercol;
@@ -351,35 +343,34 @@ std::string RUser::getName() {
     return name;
 }
 
-float RUser::getAlpha() {
-
+float RUser::getAlpha() const {
     float alpha = Pawn::getAlpha();
     //user fades out if not doing anything
-    if(elapsed - last_action > gGourceMaxUserIdle) {
-        alpha = 1.0 - std::min(elapsed - last_action - gGourceMaxUserIdle, 1.0f);
+    if(elapsed - last_action > gGourceSettings.user_idle_time) {
+        alpha = 1.0 - std::min(elapsed - last_action - gGourceSettings.user_idle_time, 1.0f);
     }
 
     return alpha;
 }
 
 bool RUser::isIdle() {
-    return (activeActions.size()==0 && actions.size()==0);
+    return (activeActions.empty() && actions.empty());
 }
 
 bool RUser::isFading() {
-    return isIdle() && (elapsed - last_action) > gGourceMaxUserIdle;
+    return isIdle() && (elapsed - last_action) > gGourceSettings.user_idle_time;
 }
 
 bool RUser::isInactive() {
     return isIdle() && (elapsed - last_action) > 10.0;
 }
 
-bool RUser::nameVisible() {
+bool RUser::nameVisible() const {
     return (Pawn::nameVisible() || highlighted) ? true : false;
 }
 
-void RUser::drawNameText(float alpha) {
-    if(gGourceHideUsers) return;
+void RUser::drawNameText(float alpha) const {
+    if(gGourceSettings.hide_users) return;
 
     float user_alpha = getAlpha();
 
@@ -397,29 +388,16 @@ void RUser::drawNameText(float alpha) {
 
         glColor4f(nameCol.x, nameCol.y, nameCol.z, (selected||highlighted) ? user_alpha : alpha);
 
-        glMatrixMode(GL_PROJECTION);
-            glPushMatrix();
-            glLoadIdentity();
-                glOrtho(0, display.width, display.height, 0, -1.0, 1.0);
+        display.push2D();
 
-         glMatrixMode(GL_MODELVIEW);
-             glPushMatrix();
-                glLoadIdentity();
+        font.draw(screenpos.x, screenpos.y, name); // above user
 
-         font.draw(screenpos.x, screenpos.y, name); // above player
-
-         glMatrixMode(GL_PROJECTION);
-            glPopMatrix();
-
-         glMatrixMode(GL_MODELVIEW);
-            glPopMatrix();
-
-        //font.draw(pos.x - (namewidth/(float)2.0), pos.y - (float)size*1.4, name.c_str()); // above player
+        display.pop2D();
     }
 }
 
 void RUser::drawActions(float dt) {
-    if(gGourceHideUsers) return;
+    if(gGourceSettings.hide_users) return;
 
     for(std::list<RAction*>::iterator it = activeActions.begin(); it != activeActions.end(); it++) {
         RAction* action = *it;
@@ -428,7 +406,7 @@ void RUser::drawActions(float dt) {
 }
 
 void RUser::draw(float dt) {
-    if(gGourceHideUsers) return;
+    if(gGourceSettings.hide_users) return;
 
     Pawn::draw(dt);
 }
